# delete

Hook for Requests 'delete' type prompts.

:param message: String message to show when prompting.
:return: Response of request in a dict

## Inputs

| Name | Type | Default | Required | Description |
| :--- | :---: | :---: | :---: | :--- |
| template_name | string |  |  | The template directory or context file without the extension used for keying the input dict values. |
| no_exit | boolean | False | X |  |
| url | string |  |  |  |
| kwargs | object | {} | X |  |


## Output
